@@ -4,8 +4,9 @@ module Network.WebSockets
     ( -- * Incoming connections and handshaking
       PendingConnection
     , pendingRequest
-    , AcceptRequest(..)
     , acceptRequest
+    , AcceptRequest(..)
+    , defaultAcceptRequest
     , acceptRequestWith
     , rejectRequest
 
@@ -23,6 +24,7 @@ module Network.WebSockets
     , send
     , sendDataMessage
     , sendTextData
+    , sendTextDatas
     , sendBinaryData
     , sendClose
     , sendPing
